<?php
/*
 * $Horde: kronolith/index.php,v 1.19.2.3 2003/02/13 00:48:04 jan Exp $
 *
 * Kronolith: Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL). If you did
 * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
 */

define('KRONOLITH_BASE', dirname(__FILE__));
$kronolith_configured = (@is_readable(KRONOLITH_BASE . '/config/conf.php') &&
                         @is_readable(KRONOLITH_BASE . '/config/prefs.php') &&
                         @is_readable(KRONOLITH_BASE . '/config/html.php'));

if ($kronolith_configured) {
    include_once KRONOLITH_BASE . '/lib/base.php';

    $uri = $prefs->getValue('defaultview') . '.php';
    if ($uri == '.php') {
        $uri = 'month.php';
    }
    if (!empty($_SERVER['QUERY_STRING'])) {
        $uri .= '?' . $_SERVER['QUERY_STRING'];
    }

    header('Location: ' . Horde::applicationUrl($uri, true));
} else {
    include KRONOLITH_BASE . '/templates/index/notconfigured.inc';
}
